#!perl
# Fruits taken from http://www.thefruitpages.com/alphabet.shtml

print "Hello world!\n";

sub apple {

}

sub banana {

}

package London;

sub alice {

}

sub bob {

}

package Tokyo;

sub foo {

}

sub bar {

} 